@@ -84,7 +84,10 @@ class PREFS(object):
             try:
                 self.CreatePrefs(prefs)
             except AttributeError:
-                self.CreatePrefs(self.prefs)                
+                try:
+                    self.CreatePrefs(self.prefs())
+                except TypeError:
+                    self.CreatePrefs(self.prefs)
 
         self.ReadPrefs()
             
